@@ -11,8 +11,7 @@
 bool PGrnIsLZ4Available;
 bool PGrnIsZlibAvailable;
 bool PGrnIsZstdAvailable;
-bool PGrnIsVectorCompressionAvailable;
-bool PGrnIsAccessorAliasAvailable;
+bool PGrnIsTemporaryIndexSearchAvailable;
 
 static grn_ctx *ctx = &PGrnContext;
 static struct PGrnBuffers *buffers = &PGrnBuffers;
@@ -39,12 +38,9 @@ PGrnInitializeGroongaInformation(void)
 	{
 		const char *libgroonga_version;
 		libgroonga_version = grn_get_version();
-		PGrnIsVectorCompressionAvailable =
+		PGrnIsTemporaryIndexSearchAvailable =
 			(atoi(libgroonga_version) >= 8 &&
-			 (strcmp(libgroonga_version, "8.0.0") != 0));
-		PGrnIsAccessorAliasAvailable =
-			(atoi(libgroonga_version) >= 8 &&
-			 (strcmp(libgroonga_version, "8.0.0") != 0));
+			 (strcmp(libgroonga_version, "8.0.2") > 0));
 	}
 
 	GRN_OBJ_FIN(ctx, &grnIsSupported);
@@ -382,6 +378,14 @@ PGrnCreateColumnWithSize(Relation	index,
 	return column;
 }
 
+void
+PGrnIndexColumnClearSources(Relation index,
+							grn_obj *indexColumn)
+{
+	GRN_BULK_REWIND(&(buffers->sourceIDs));
+	PGrnIndexColumnSetSourceIDs(index, indexColumn, &(buffers->sourceIDs));
+}
+
 void
 PGrnIndexColumnSetSource(Relation index,
 						 grn_obj *indexColumn,
